class _NoDetailsProvided(Exception):
    pass

class _InvalidCategory(Exception):
    pass   

class _NonNumericAppID(Exception):
    # user didn't provide any paramater to fetch data
    pass

class _InvalidURL(Exception):
    pass 